A dataset of tallgrass prairie plant composition at one annually burned and one unburned site over time at the Konza Prairie LTER, Manhattan Kansas (Collins et al. 2008).
data(collins08)A data frame with 2058 rows and 4 variables
A data frame containing a column for replicate, year, species and abundance: - **replicate**: A factor column of spatial replicates with two levels ("annually burned" and "unburned") - **year**: An integer column of sampling time points - **species**: A factor column of species sampled - **abundance**: A numeric column of abundance values