Learn R Programming

codyn (version 2.0.6)

knz_001d: Data from Konza Prairie, watershed 001d

Description

Plant composition within multiple replicates at an annually burned tallgrass prairie site in the Konza Prairie LTER, Manhattan KS (Watershed 001d).

Usage

data(knz_001d)

Arguments

Format

A data frame with 8768 rows and 4 variables

Details

A data frame containing a column for species, year, subplot and abundance: - **species**: A factor column of species sampled - **year**: An integer column of sampling time points - **subplot**: A factor column of spatial replicates with 20 levels - **abundance**: A numeric column of abundance values