Learn R Programming

codyn (version 2.0.6)

pplots: Phosphorus plots data from Avolio et al. 2014

Description

A dataset of tallgrass prairie plant composition in a nitrogen and phosphorus addition experiment at Konza Prairie, Manhattan Kansas (Avolio et al. 2014). This dataset is a subset of the full dataset.

Usage

data(pplots)

Arguments

Format

A data frame with 1232 rows and 6 variables

Details

A data frame containing a column for replicate, year, species, abundance, block and treatment : - **plot**: An integer column of spatial replicates with 18 levels (6-48) - **year**: An integer column of sampling time points - **species**: A factor column of species sampled - **relative_cover**: A numeric column of relative cover values - **block**: An integer column of dummy blocking variable, grouping treatment plots into blocks - **treatment**: A factor column of nitrogen and phosphorus treatments applied to the plots