Plant composition within multiple replicates at an annually burned tallgrass prairie site in the Konza Prairie LTER, Manhattan KS (Watershed 001d).
data(knz_001d)A data frame with 8768 rows and 4 variables
A data frame containing a column for species, year, subplot and abundance: - **species**: A factor column of species sampled - **year**: An integer column of sampling time points - **subplot**: A factor column of spatial replicates with 20 levels - **abundance**: A numeric column of abundance values